@@ -147,16 +147,16 @@ base_mappings = {
         "UPPER ROTLIEGEND2 FM": 260,
         "KUPFERSCHIEFER FM": 257,
         "ZECHSTEIN FM": 255,  # new
-        "BUNTER SHALE FM": 251,  # new, in Bacton GP
-        "SMITH BANK FM": 250,
+        "BUNTER SHALE FM": 250,  # new, in Bacton GP
         "BUNTER SANDSTONE FM": 249,  # new, in Bacton GP
+        "SMITH BANK FM": 248,
         "TEIST FM": 240,
         "LOMVI FM": 235,
-        "SKAGERRAK FM": 230,
+        "SKAGERRAK FM": 228,
         "ALKE FM": 227,
         "LUNDE FM": 214,
-        "GASSUM FM": 202,
-        "RAUDE FM": 201,
+        "GASSUM FM": 203,
+        "RAUDE FM": 202,
         "EIRIKSSON FM": 198,
         "aaRE FM": 197,
         "AMUNDSEN FM": 195.5,
@@ -189,7 +189,7 @@ base_mappings = {
         "FENSFJORD FM": 162.5,
         "MELKE FM": 161,
         "INTRA MELKE FM SS": 161,
-        "HAUGESUND FM": 159,
+        "HAUGESUND FM": 159.5,
         "EGERSUND FM": 158.5,
         "ULA FM": 158,
         "SPEKK FM": 157.5,
@@ -290,29 +290,29 @@ base_mappings = {
     },
     "groups_map": {
         "BASEMENT": 444,  # Pre-Devonian, set to be equal to silur
-        "ROTLIEGEND GP": 299,
+        "ROTLIEGEND GP": 295,
         "ZECHSTEIN GP": 259,
         "BACTON GP": 252,  # new
-        "HEGRE GP": 251,
-        "LOLLAND GP": 230,  # new
+        "HEGRE GP": 249.5,
+        "LOLLAND GP": 229,  # new
         "JYLLAND GP": 220,  # new
-        "MORS GP": 210,  # new
         "RED BEDS (INFORMAL)": 226,
         "GREY BEDS (INFORMAL)": 212,
-        "STATFJORD GP": 202,
+        "MORS GP": 210,  # new
+        "STATFJORD GP": 204,
         "BaaT GP": 201,
         "DUNLIN GP": 196,
         "VESTLAND GP": 175,
-        "BRENT GP": 174,
-        "FANGST GP": 172,
+        "FANGST GP": 171.5,
         "FLADEN GP": 169,
-        "VIKING GP": 164,
-        "BOKNFJORD GP": 161,
+        "BRENT GP": 168,
+        "VIKING GP": 162,
+        "BOKNFJORD GP": 160,
         "TYNE GP": 159,
         "CROMER KNOLL GP": 140,
-        "SHETLAND GP": 97,
+        "SHETLAND GP": 98,
         "ROGALAND GP": 63,
-        "HORDALAND GP": 53,
+        "HORDALAND GP": 52,
         "NORDLAND GP": 19,
         # Barents sea
         # "BILLEFJORDEN GP": 350,
@@ -337,7 +337,7 @@ base_mappings = {
         "CRETACEOUS SY": 145.5,
         # Add "s" to the names to don't mix them with:
         "ROGALANDS SY": 63,
-        "HORDALANDS SY": 53,
+        "HORDALANDS SY": 52,
         "NORDLANDS SY": 19,
     },
 }
