@@ -1,3 +1,4 @@
+import warnings
 from typing import Any, Dict, List
 
 import lasio
@@ -49,7 +50,7 @@ class DataLoader(object):
         data = []
         for head in heads:
             training_data = client.sequences.data.retrieve_dataframe(
-                id=head.id, start=None, end=None
+                id=head.id, start=0, end=None
             )
             try:
                 training_data["well_name"] = head.metadata["wellbore"]
@@ -62,7 +63,9 @@ class DataLoader(object):
             df.to_pickle(save_as)
         return self.save_df_to_cls(df)
 
-    def load_from_las(self, filepaths: List[str], **kwargs: Any) -> DataFrame:
+    def load_from_las(
+        self, filepaths: List[str], metadata=None, **kwargs: Any
+    ) -> DataFrame:
         """
         Loads data from las file(s)
 
@@ -71,21 +74,38 @@ class DataLoader(object):
 
         Args:
             filepaths (list of strings): paths to las files
+            metadata (list of strings): attributes to extract from las file. These
+                must match header item names!
 
         Returns:
             DataFrame: Returns the data loaded from the provided las files.
         """
+        if metadata is None:
+            metadata = ["WELL", "SET"]
         dfs = []
         for path in filepaths:
             las = lasio.read(path)
-            well = las.header["Well"].WELL.value
-            try:
-                dataset = las.params.SET.value
-            except AttributeError:
-                dataset = np.nan
             df = las.df().reset_index()
-            df["well_name"] = well
-            df["datasetName"] = dataset
+            for attr in metadata:
+                with warnings.catch_warnings():
+                    warnings.filterwarnings(
+                        "ignore",
+                        category=FutureWarning,
+                        message=(
+                            ".*The default dtype for empty Series will be 'object'.*"
+                        ),
+                    )
+                    try:
+                        df[attr] = las.well[attr].value
+                    except KeyError:
+                        try:
+                            df[attr] = las.params[attr].value
+                        except KeyError:
+                            warnings.warn(
+                                f"Attribute {attr} not found in las file {path}. "
+                                f"Available attributes are {sorted(set([*las.well.keys(), *las.params.keys()]))}"
+                            )
+                            df[attr] = np.nan
             dfs.append(df)
         return self.save_df_to_cls(pd.concat(dfs, axis=0))
 
