@@ -74,6 +74,7 @@ class Dataset(dl.DataLoader):
     petrophysical_features: List[str]
     keep_columns: List[str]
     preprocessing_pipeline: Dict[str, Dict[str, Any]]
+    verbose: bool
 
     def __set_defaults(self) -> None:
         """
@@ -88,6 +89,9 @@ class Dataset(dl.DataLoader):
         if not hasattr(self, "keep_columns"):
             self.keep_columns = []
 
+        if not hasattr(self, "verbose"):
+            self.verbose = True
+
     def __handle_paths(self, path: Union[Path, str]) -> Union[Path, str]:
         """
         A helper function to handle paths passed either directly to the class
@@ -401,7 +405,7 @@ class Dataset(dl.DataLoader):
             self.categorical_curves = [self.id_column]
 
     def preprocess(  # noqa: C901
-        self, df: Optional[DataFrame] = None, verbose=True, **kwargs
+        self, df: Optional[DataFrame] = None, verbose=None, **kwargs
     ) -> DataFrame:
         """
         Main preprocessing function. Pass the dataframe to be preprocessed along
@@ -455,6 +459,9 @@ class Dataset(dl.DataLoader):
                     "This Dataset class instance does not have a pd.DataFrame "
                     "attached to it so there is no data to preprocess!"
                 )
+        # If verbose specified in the function call, overwrite the class attribute
+        if verbose is not None:
+            self.verbose = verbose
 
         # Ingest the kwargs to the class instance, if the pipeline was defined
         # in the settings file it will have already been ingested when the class
@@ -512,7 +519,10 @@ class Dataset(dl.DataLoader):
 
         # <---------------- Perform preprocessing pipeline ------------------> #
         pbar = tqdm(
-            kwargs.items(), desc="Preprocessing", disable=(not verbose), unit="function"
+            kwargs.items(),
+            desc="Preprocessing",
+            disable=(not self.verbose),
+            unit="function",
         )
         artifacts = {}
         start_columns = set(df.columns)
@@ -600,7 +610,10 @@ class Dataset(dl.DataLoader):
         """
         # Define per method defaults
         defaults: Dict[str, Dict[str, Any]] = {
-            "add_log_features": {"log_features": getattr(self, "log_features", None)},
+            "add_log_features": {
+                "log_features": getattr(self, "log_features", None),
+                "num_filler": getattr(self, "num_filler", None),
+            },
             "add_gradient_features": {
                 "gradient_features": getattr(self, "gradient_features", None)
             },
