@@ -5,7 +5,6 @@ from typing import Any, Dict, List, Union
 import numpy as np
 import pandas as pd
 from cognite.client import CogniteClient
-from scipy.interpolate import interp1d
 
 import akerbp.mlpet.petrophysical_features as petro
 import akerbp.mlpet.utilities as utilities
@@ -26,14 +25,26 @@ def add_log_features(
     Keyword Args:
         log_features (list, optional): list of column names for the columns that should be
             loggified. Defaults to None
+        num_filler (float, optional): value that represents a missing value in the
+            log_features. Defaults to None.
 
     Returns:
         pd.DataFrame: New dataframe with calculated log columns
     """
     log_features: List[str] = kwargs.get("log_features", None)
+    num_filler: float = kwargs.get("num_filler", None)
     if log_features is not None:
+        if num_filler is not None:
+            nf_masks = {}
+            for col in log_features:
+                nf_masks[col] = df[col].eq(num_filler)
+                df.loc[nf_masks[col], col] = np.nan
         log_cols = [col + "_log" for col in log_features]
         df[log_cols] = np.log10(df[log_features].clip(lower=0) + 1)
+        if num_filler is not None:
+            for col, mask in nf_masks.items():
+                df.loc[mask, col] = num_filler  # Set back
+                df.loc[mask, col + "_log"] = num_filler  # Ensure log corresponds
     return df
 
 
@@ -424,8 +435,8 @@ def add_formations_and_groups(
             ) from exc
     df_ = df.copy()
     if id_column is not None and formation_tops_mapper:
-        df_["GROUP"] = "UNKNOWN"
-        df_["FORMATION"] = "UNKNOWN"
+        df_.loc[:, "GROUP"] = "UNKNOWN"
+        df_.loc[:, "FORMATION"] = "UNKNOWN"
 
         for well in df_[id_column].unique():
             try:
@@ -465,7 +476,7 @@ def add_formations_and_groups(
                 include_lowest=True,
                 right=False,
                 ordered=False,
-            )
+            ).astype("object")
 
             df_.loc[well_df.index, "FORMATION"] = pd.cut(
                 well_df[depth_column],
@@ -474,7 +485,7 @@ def add_formations_and_groups(
                 include_lowest=True,
                 right=False,
                 ordered=False,
-            )
+            ).astype("object")
         df_ = utilities.normalize_group_formation_system(df_, add_systems)
 
     else:
@@ -485,27 +496,139 @@ def add_formations_and_groups(
     return df_
 
 
+def add_trajectory_data(
+    df: pd.DataFrame,
+    **kwargs,
+) -> pd.DataFrame:
+    """Add trajectory data to the provided dataframe.
+    The type of trajectory data added is governed by the keyword argument 'trajectory_type', and
+    the default behaviour is to add both wellbore coordinates and vertical depths.
+
+    Args:
+        df (pd.DataFrame): input data
+
+    Keyword Args:
+        md_column (str): Name of the column containing the measured depth values
+            Defaults to None
+        id_column (str): Name of the column containing the well names
+            Defaults to None
+        client (CogniteClient): Cognite client to use for retrieving data from CDF
+            Defaults to None
+        trajectory_type (str): Type of trajectory data to add. Can be one of 'coordinates' and 'vertical_depths'
+            Defaults to None, where both wellbore coordinates and vertical depths are added
+        trajectory_mapping (Dict[str, Dict[str, List[float]]]): trajectory mapping to use.
+            Defaults to {}, in which the mapping is retrieved from CDF
+
+    Raises:
+        ValueError: Due to missing or invalid specification of keyword arguments
+        Exception: Generic exception if something fails in retrieval of the trajectory data from CDF
+
+    Returns:
+        pd.DataFrame: output data with trajectory columns added
+    """
+    md_column: str = kwargs.get("md_column", None)
+    id_column: str = kwargs.get("id_column", None)
+    client: CogniteClient = kwargs.get("client", None)
+    trajectory_type: str = kwargs.get("trajectory_type", None)
+    trajectory_mapping: Dict[str, Dict[str, List[float]]] = kwargs.get(
+        "trajectory_mapping", {}
+    )
+    retrieve_from_cdf: bool = kwargs.get("retrieve_from_cdf", not trajectory_mapping)
+
+    if id_column is None:
+        raise ValueError("No id_column kwarg provided!")
+    if retrieve_from_cdf:
+        if client is None:
+            client = utilities.get_cognite_client()
+        try:
+            if trajectory_type is not None:
+                if trajectory_type == "coordinates":
+                    trajectory_mapping = utilities.get_wellbore_coordinates(
+                        well_names=df[id_column].unique(),
+                        client=client,
+                    )
+                elif trajectory_type == "vertical_depths":
+                    trajectory_mapping = utilities.get_vertical_depths(
+                        well_names=df[id_column].unique(),
+                        client=client,
+                    )
+                else:
+                    raise ValueError("Invalid trajectory_type provided!")
+            else:
+                trajectory_mapping = utilities.get_trajectory_mapper_from_cdf(
+                    well_names=df[id_column].unique(),
+                    client=client,
+                )
+            if len(trajectory_mapping) == 0:
+                raise Exception(
+                    "No trajectory data was retrieved from CDF. "
+                    "A possible explanation is missing trajectoy data in CDF."
+                )
+        except ValueError as e:
+            raise ValueError(e) from e
+        except Exception as exc:
+            raise Exception(
+                "Something failed in the retrieval of the vertical depths mapping. "
+                "Please check the error message below and try again.\n\n"
+                f"{exc}"
+            ) from exc
+    if md_column is not None and id_column is not None:
+        df_ = utilities.interpolate_discrete_trajectory_data_along_wellbore(
+            df, id_column, md_column, trajectory_mapping=trajectory_mapping
+        )
+    else:
+        raise ValueError(
+            "The vertical depths could not be added to the provided dataframe"
+            " because required keyword arguments are missing (id_column, md_column).)"
+        )
+    return df_
+
+
+def add_wellbore_coordinates(
+    df: pd.DataFrame,
+    **kwargs,
+) -> pd.DataFrame:
+    """Add wellbore coordinates, i.e. X and Y, as columns to the input dataframe.
+
+    Args:
+        df (pd.DataFrame): input data
+
+    Keyword Args:
+        md_column (str): identifier for the measured depth column in the provided dataframe
+            Defaults to None
+        id_column (str): identifier for the well name column in the provided dataframe
+            Defaults to None
+        client (CogniteClient): Cognite client to use for retrieving data from CDF
+            Defaults to None
+        trajectory_mapping (Dict[str, Dict[str, List[float]]]): trajectory mapping to use
+            Defaults to {}, in which the mapping is retrieved from CDF
+
+
+    Returns:
+        pd.DataFrame: _description_
+    """
+    kwargs["trajectory_type"] = "coordinates"
+    return add_trajectory_data(df, **kwargs)
+
+
 def add_vertical_depths(
     df: pd.DataFrame,
     **kwargs,
 ) -> pd.DataFrame:
     """Add vertical depths, i.e. TVDKB, TVDSS and TVDBML, to the input dataframe.
-    This function relies on a keyword argument for a vertical depth mapper dictionary,
-    created by querying CDF at discrete points along the wellbore for each well.
-    To map the vertical depths along the entire wellbore, the data in the dictionary is interpolated by using the measured depth
 
     Args:
-        df (pd.DataFrame): pandas dataframe to add vertical depths to
+        df (pd.DataFrame): input data
 
     Keyword Args:
         md_column (str): identifier for the measured depth column in the provided dataframe
             Defaults to None
         id_column (str): identifier for the well column in the provided dataframe
             Defaults to None
-        vertical_depths_mapper (dict): dictionary containing vertical- and measured depths
+        trajectory_mapping (dict): dictionary containing vertical- and measured depths
             queried from CDF at discrete points along the wellbore for each well. For example::
 
-                vertical_depths_mapper = {
+                trajectory_mapping = {
                     "25/6-2": {
                         "TVDKB": [0.0, 145.0, 149.9998, ...],
                         "TVDSS": [-26.0, 119.0, 123.9998, ...],
@@ -523,60 +646,8 @@ def add_vertical_depths(
     Returns:
         pd.DataFrame: dataframe with additional column for TVDKB, TVDSS and TVDBML
     """
-    md_column: str = kwargs.get("md_column", None)
-    id_column: str = kwargs.get("id_column", None)
-    client: CogniteClient = kwargs.get("client", None)
-    vertical_depths_mapper: Dict[str, Dict[str, List[float]]] = kwargs.get(
-        "vertical_depths_mapper", {}
-    )
-    retrieve_from_cdf: bool = kwargs.get(
-        "retrieve_from_cdf", not vertical_depths_mapper
-    )
-
-    if id_column is None:
-        raise ValueError("No id_column kwarg provided!")
-    if retrieve_from_cdf:
-        if client is None:
-            client = utilities.get_cognite_client()
-        try:
-            vertical_depths_mapper = utilities.get_vertical_depths(
-                well_names=df[id_column].unique(), client=client
-            )
-        except Exception as exc:
-            raise Exception(
-                "Something failed in the retrieval of the vertical depths mapping. "
-                "Please check the error message below and try again.\n\n"
-                f"{exc}"
-            ) from exc
-    if (
-        md_column is not None
-        and id_column is not None
-        and len(vertical_depths_mapper) != 0
-    ):
-        df_ = df.copy()
-        for well in vertical_depths_mapper:
-            md_interpolate = df_.loc[df_[id_column] == well, md_column].to_list()
-            depths = vertical_depths_mapper[well]
-            md = depths["MD"]
-            for key in depths.keys():
-                if key == "MD":
-                    continue
-                vertical_depth = depths[key]
-                with warnings.catch_warnings(record=True) as w:
-                    f = interp1d(x=md, y=vertical_depth, fill_value="extrapolate")
-                    interpolated_vertical_depth = f(md_interpolate)
-                if w:
-                    warnings.warn(
-                        f"Interpolating {key} for well {well} triggered a "
-                        f"runtime warning: {w[0].message}"
-                    )
-                df_.loc[df_[id_column] == well, key] = interpolated_vertical_depth
-    else:
-        raise ValueError(
-            "The vertical depths could not be added to the provided dataframe"
-            " because some keyword arugments were missing!"
-        )
-    return df_
+    kwargs["trajectory_type"] = "vertical_depths"
+    return add_trajectory_data(df, **kwargs)
 
 
 def add_depth_trend(df: pd.DataFrame, **kwargs):
