@@ -14,15 +14,11 @@ from sklearn.impute._base import _BaseImputer
 from sklearn.linear_model import BayesianRidge, LinearRegression
 from sklearn.preprocessing import PolynomialFeatures
 
-from akerbp.mlpet.utilities import (
-    get_col_types,
-    standardize_group_formation_name,
-    standardize_names,
-)
+import akerbp.mlpet.utilities as utilities
 
 
 def simple_impute(
-    df: DataFrame,
+    df_: DataFrame,
     **kwargs,
 ) -> DataFrame:
     """
@@ -36,7 +32,7 @@ def simple_impute(
     Keyword Args:
         categorical_curves: List of column names that should be considered as
             categorical. If not provided, defaults to trying to determine these
-            using the get_col_types utility function
+            using the utilities.get_col_types utility function
         depth_column: The name of the depth column to be excluded from imputation
             if desired. Defaults to None
 
@@ -44,8 +40,11 @@ def simple_impute(
         tuple: dataframe with imputed values and a dictionary containing the
             fitted imputers
     """
+    df = df_.copy()
     depth_column: str = kwargs.get("depth_column", None)
-    num_cols, cat_cols = get_col_types(df, kwargs.get("categorical_curves", None))
+    num_cols, cat_cols = utilities.get_col_types(
+        df, kwargs.get("categorical_curves", None)
+    )
 
     # Impute numerical columns
     missing_cols_num = df[num_cols].isnull().sum().gt(0).index.tolist()
@@ -92,7 +91,7 @@ def iterative_impute(df: DataFrame, **kwargs) -> DataFrame:
     imputer: _BaseImputer = kwargs.get("imputer")
     # Only interested in numerical columns so no need to flood console with
     # warnings related to categorical curves
-    num_cols, _ = get_col_types(df, warn=False)
+    num_cols, _ = utilities.get_col_types(df, warn=False)
 
     # Iterative impute
     missing_featutes = df[num_cols].isnull().sum().gt(0).index.tolist()
@@ -107,7 +106,7 @@ def iterative_impute(df: DataFrame, **kwargs) -> DataFrame:
     return df
 
 
-def generate_imputation_models(df: DataFrame, **kwargs) -> Dict[str, Dict[str, Any]]:
+def generate_imputation_models(df_: DataFrame, **kwargs) -> Dict[str, Dict[str, Any]]:
     """
     Generates 3rd order polynomial regression models with the DEPTH column as the
     target y variable and each curve in the provided curves keyword argument as the
@@ -126,6 +125,7 @@ def generate_imputation_models(df: DataFrame, **kwargs) -> Dict[str, Dict[str, A
     Returns:
         dict: dictionary with models for each curve based on DEPTH
     """
+    df = df_.copy()
     curves: List[str] = kwargs.get("curves", [])
     depth_column: str = kwargs.get("depth_column", "DEPTH")
     imputation_models = {c: {"poly_transform": None, "model": None} for c in curves}
@@ -214,7 +214,7 @@ def individual_imputation_models(df: DataFrame, **kwargs) -> Dict[str, Dict[str,
     return imputation_models
 
 
-def apply_depth_trend_imputation(df: DataFrame, **kwargs) -> DataFrame:
+def apply_depth_trend_imputation(df_: DataFrame, **kwargs) -> DataFrame:
     """
     Apply imputation models to impute curves in given dataframe
 
@@ -229,6 +229,7 @@ def apply_depth_trend_imputation(df: DataFrame, **kwargs) -> DataFrame:
     Returns:
         pd.DataFrame: dataframe with imputed values based on depth trend
     """
+    df = df_.copy()
     # Process kwargs
     curves: List[str] = kwargs.get("curves", [])
 
@@ -294,7 +295,7 @@ def impute_depth_trend(
     if curves:
         # we need to first standardize names if possible
         if curves_mappings:
-            curves, _ = standardize_names(curves, curves_mappings)
+            curves, _ = utilities.standardize_names(curves, curves_mappings)
 
         # check if depth and all other curves in df
         if not all(c in df.columns for c in curves + ["DEPTH"]):
@@ -383,7 +384,7 @@ def fillna_callibration_values(
 
     df_ = df.copy()
     if standardize_level_names and level in ["FORMATION", "GROUP"]:
-        df_[level] = df[level].apply(standardize_group_formation_name)
+        df_[level] = df[level].apply(utilities.standardize_group_formation_name)
     for well in df_[id_column].unique():
         for c in curves:
             df_.loc[df_[id_column] == well, c] = df_.loc[
