@@ -403,8 +403,6 @@ def calculate_VSH(df: pd.DataFrame, **kwargs):
     version: str = kwargs.get("version", None)
     return_CI: bool = kwargs.get("return_CI", False)
     user_kwargs: Dict[str, Any] = kwargs.get("keyword_arguments", None)
-    kubeflow_model_url = kwargs.get("kubeflow_model_url", None)
-    request_header = kwargs.get("request_header", None)
 
     # Validate input parameters
     if id_column is None:
@@ -429,35 +427,19 @@ def calculate_VSH(df: pd.DataFrame, **kwargs):
         else:
             df["FORMATION_GROUP"] = user_kwargs["nan_textual_value"]
 
-    if kubeflow_model_url is None:
-        if version is None:
-            version = "latest"
-            external_id = f"automatic_vsh-prediction-{env}"
-        else:
-            external_id = f"automatic_vsh-prediction-{env}-{version}"
-        df_ = utilities.run_deployed_model(
-            df=df,
-            id_column=id_column,
-            keyword_arguments=user_kwargs,
-            cdf_external_id=external_id,
-            client=client,
-        )
+    if version is None:
+        version = "latest"
+        external_id = f"automatic_vsh-prediction-{env}"
     else:
-        if request_header is None:
-            df_ = utilities.run_deployed_model(
-                df=df,
-                id_column=id_column,
-                keyword_arguments=user_kwargs,
-                kubeflow_model_url=kubeflow_model_url,
-            )
-        else:
-            df_ = utilities.run_deployed_model(
-                df=df,
-                id_column=id_column,
-                keyword_arguments=user_kwargs,
-                kubeflow_model_url=kubeflow_model_url,
-                header=request_header,
-            )
+        external_id = f"automatic_vsh-prediction-{env}-{version}"
+    df_ = utilities.run_deployed_model(
+        df=df,
+        id_column=id_column,
+        keyword_arguments=user_kwargs,
+        cdf_external_id=external_id,
+        client=client,
+    )
+
     # For akerbp.mlpet purposes (mostly as feat eng for ML Models) we want to
     # rename VSH_AUT to VSH for better compability with preprocessing
     df_ = df_.rename(columns={"VSH_AUT": "VSH"})
