@@ -167,16 +167,9 @@ def plot_default_well_profile(
 
 def plot_well_profile_missedpay(
     well_name: str,
-    df_input: pd.DataFrame,
-    df_result: pd.DataFrame,
+    dfs: Dict[str, pd.DataFrame],
     id_column: str,
     md_column: str,
-    extend_formation_top_lines: bool = False,
-    extend_group_top_lines: bool = True,
-    lithology_numbers: Dict[int, Dict[str, Any]] = lithology_numbers,
-    lithology_conf_numbers: Dict[float, Dict[str, Any]] = lithology_conf_numbers,
-    figsize: Tuple[int, int] = (1500, 1000),
-    show_fig: bool = False,
     **kwargs,
 ) -> go.Figure:
     """
@@ -202,18 +195,19 @@ def plot_well_profile_missedpay(
 
     Args:
         well_name (str): wellbore name
-        df_input (pd.DataFrame): dataframe with colums to plot. The data in this dataframe is raw.
-        df_result (pd.DataFrame): dataframe wiht column to plot. The data in this dataframe is preprocessed.
+        df (Dict[str, pd.DataFrame]): Dict of dataframes.
+            "input" key: dataframe with colums to plot. The data in this dataframe is raw.
+            "result" key: dataframe wiht column to plot. The data in this dataframe is preprocessed.
         id_column (str): name of well name column in df
         md_column (str): name of depth column in df
-        features_to_plot (List[str], optional): list of features to plot. Defaults to [ "MUDGAS", "AC", "NEU/DEN", "GR", "VSH", "RDEP", "CALI/BS", "COAL/CALC_flag", "MUD/LOG_indicator", "MissedPay prediction", "LITHOLOGY", "FORMATION", "GROUP"].
         extend_formation_top_lines (bool, optional): Whether to exted the formation top lines across all subplots. Defaults to False.
         extend_group_top_lines (bool, optional): Whether to exted the group top lines across all subplots. Defaults to False.
         lithology_numbers (Dict[int, Dict[str, Any]]): dictionary with lithology numbers as key with human readable name['lith'] and color['color'] for plot as value. Defaults to lithology_numbers Dict in akerbp.mlpet.plotting_variables.py.
         lithology_conf_numbers (Dict[float, Dict[str, Any]]): dictionary with lithology conf numbers as key with color for plot as value['color']. Defaults to lithology_conf_numbers Dict in akerbp.mlpet.plotting_variables.py.
         figsize (Tuple[int, int], optional): figure size (W x H) in pixels. Defaults to (1500, 1000).
         show_fig (bool, optional): Wheter to save fig. If False the figure will be returned by the function. Defaults to False.
-
+        features_to_plot (List[str], optional): list of features to plot. Defaults to [ "MUDGAS", "AC", "NEU/DEN", "GR", "VSH", "RDEP", "CALI/BS", "COAL/CALC flag", "MUD/LOG indicator", "MissedPay prediction", "LITHOLOGY", "FORMATION", "GROUP"].
+        curve_function_dataset_mapper (Dict[str, str])
     Returns:
         go.Figure: plotly graph_object Figure
     """
@@ -236,16 +230,33 @@ def plot_well_profile_missedpay(
             "GROUP",
         ],
     )
+    curve_function_dataset_mapper: Dict[str, str] = kwargs.get(
+        "curve_function_dataset_mapper", {}
+    )
+    extend_formation_top_lines: bool = kwargs.get("extend_formation_top_lines", False)
+    extend_group_top_lines: bool = kwargs.get("extend_group_top_lines", True)
+    lithology_numbers: Dict[int, Dict[str, Any]] = kwargs.get(
+        "lithology_numbers", plotting_variables.lithology_numbers
+    )
+    lithology_conf_numbers: Dict[float, Dict[str, Any]] = kwargs.get(
+        "lithology_conf_numbers", plotting_variables.lithology_conf_numbers
+    )
+    figsize: Tuple[int, int] = kwargs.get("figsize", (1500, 1000))
+    show_fig: bool = kwargs.get("show_fig", False)
 
-    df_input = df_input[df_input[id_column] == well_name].sort_values(md_column)
-    df_result = df_result[df_result[id_column] == well_name].sort_values(md_column)
+    dfs["input"] = dfs["input"][dfs["input"][id_column] == well_name].sort_values(
+        md_column
+    )
+    dfs["result"] = dfs["result"][dfs["result"][id_column] == well_name].sort_values(
+        md_column
+    )
 
     # Map curve names in the provided dataframe
-    df_input = utilities.standardize_curve_names(
-        df=df_input, mapper=default_mappings.base_mappings["curve_mappings"]
+    dfs["input"] = utilities.standardize_curve_names(
+        df=dfs["input"], mapper=default_mappings.base_mappings["curve_mappings"]
     )
-    df_result = utilities.standardize_curve_names(
-        df=df_result, mapper=default_mappings.base_mappings["curve_mappings"]
+    dfs["result"] = utilities.standardize_curve_names(
+        df=dfs["result"], mapper=default_mappings.base_mappings["curve_mappings"]
     )
     id_column = default_mappings.base_mappings["curve_mappings"][id_column]
 
@@ -274,21 +285,21 @@ def plot_well_profile_missedpay(
     curve_function_mapper: Dict[str, Dict[Any, Any]] = {
         "AC": {
             plotting_helpers.add_AC: {
-                "df": df_input,
+                "df": dfs["input"],
                 "curve_name": "AC",
                 "md_column": md_column,
             }
         },
         "RDEP": {
             plotting_helpers.add_RDEP: {
-                "df": df_input,
+                "df": dfs["input"],
                 "curve_name": "RDEP",
                 "md_column": md_column,
             }
         },
         "NEU/DEN": {
             plotting_helpers.add_NEU_DEN: {
-                "df": df_input,
+                "df": dfs["input"],
                 "den_curve_name": "DEN",
                 "neu_curve_name": "NEU",
                 "md_column": md_column,
@@ -296,14 +307,14 @@ def plot_well_profile_missedpay(
         },
         "GR": {
             plotting_helpers.add_GR: {
-                "df": df_input,
+                "df": dfs["input"],
                 "curve_name": "GR",
                 "md_column": md_column,
             }
         },
         "MUDGAS": {
             plotting_helpers.add_MUDGAS: {
-                "df": df_input,
+                "df": dfs["input"],
                 "methane_curve_name": "MTHA",
                 "ethane_curve_name": "ETHA",
                 "propane_curve_name": "PRPA",
@@ -312,29 +323,30 @@ def plot_well_profile_missedpay(
         },
         "VSH": {
             plotting_helpers.add_VSH: {
-                "df": df_result,
+                "df": dfs["input"],
                 "curve_name": "VSH",
                 "md_column": md_column,
             }
         },
         "CALI/BS": {
             plotting_helpers.add_CALI_BS: {
-                "df": df_input,
+                "df": dfs["input"],
                 "cali_curve_name": "CALI",
                 "bs_curve_name": "BS",
                 "md_column": md_column,
             }
         },
         "VSH_flag_filter": {
-            plotting_helpers.add_VSH_flag_filter: {
-                "df": df_result,
+            plotting_helpers.add_binary_curve: {
+                "df": dfs["input"],
+                "flag_color": "red",
                 "curve_name": "filter_vsh_cutoff",
                 "md_column": md_column,
             }
         },
         "COAL/CALC flag": {
             plotting_helpers.add_COAL_CALC_flag: {
-                "df": df_result,
+                "df": dfs["input"],
                 "coal_curve_name": "coal_flag",
                 "calc_curve_name": "calc_flag",
                 "md_column": md_column,
@@ -342,24 +354,24 @@ def plot_well_profile_missedpay(
         },
         "MUD/LOG indicator": {
             plotting_helpers.add_mud_log_indicator: {
-                "df": df_result,
-                "mud_indicator_curve_name": "mud_indicator",
-                "log_indicator_curve_name": "log_indicator",
+                "df": dfs["input"],
+                "mud_indicator_curve_name": "PAY_FLAG_MUD_RESPONSE_ML",
+                "log_indicator_curve_name": "PAY_FLAG_LOG_RESPONSE_ML",
                 "md_column": md_column,
             }
         },
         "MissedPay prediction": {
             plotting_helpers.add_missedpay_prediction: {
-                "df": df_result,
+                "df": dfs["input"],
                 "prediction_label": "ML Pay Prediction",
-                "probability_curve_name": "probabilities",
-                "flag_curve_name": "predictions",
+                "probability_curve_name": "PAY_FLAG_PROB_ML",
+                "flag_curve_name": "PAY_FLAG_ML",
                 "md_column": md_column,
             }
         },
         "LITHOLOGY": {
             plotting_helpers.add_LITHOLOGY: {
-                "df": df_result,
+                "df": dfs["input"],
                 "lithology_prediction_curve_name": "LITHOLOGY",
                 "lithology_confidence_curve_name": "LITHOLOGY_CONF",
                 "md_column": md_column,
@@ -369,7 +381,7 @@ def plot_well_profile_missedpay(
         },
         "FORMATION": {
             plotting_helpers.add_formations_and_groups: {
-                "df": df_input,
+                "df": dfs["input"],
                 "ncols": ncols,
                 "id_column": id_column,
                 "md_column": md_column,
@@ -380,7 +392,7 @@ def plot_well_profile_missedpay(
         },
         "GROUP": {
             plotting_helpers.add_formations_and_groups: {
-                "df": df_input,
+                "df": dfs["input"],
                 "ncols": ncols,
                 "id_column": id_column,
                 "md_column": md_column,
@@ -391,9 +403,17 @@ def plot_well_profile_missedpay(
         },
     }
 
+    # Overwrite dataset from provided input
+    for feature in curve_function_dataset_mapper.keys():
+        if feature in curve_function_mapper.keys():
+            for function in curve_function_mapper[feature]:
+                curve_function_mapper[feature][function]["df"] = dfs[
+                    curve_function_dataset_mapper[feature]
+                ]
+
     fig = plotting_helpers.initialize_figure(
         well_name=well_name,
-        depth_values=df_input[md_column],
+        depth_values=dfs["input"][md_column],
         ncols=ncols,
         figsize=figsize,
     )
@@ -412,7 +432,7 @@ def plot_well_profile_missedpay(
                 fig = plotting_helpers.add_curve(
                     fig=fig,
                     i_curve=i_curve + 1,
-                    df=df_input,
+                    df=dfs["input"],
                     curve_name=curve_name,
                     md_column=md_column,
                 )
@@ -420,7 +440,7 @@ def plot_well_profile_missedpay(
                 fig = plotting_helpers.add_curve(
                     fig=fig,
                     i_curve=i_curve + 1,
-                    df=df_result,
+                    df=dfs["result"],
                     curve_name=curve_name,
                     md_column=md_column,
                 )
