@@ -1,4 +1,4 @@
-from typing import Any, Dict, Tuple
+from typing import Any, Dict, List, Tuple
 
 import numpy as np
 import pandas as pd
@@ -68,6 +68,254 @@ def initialize_figure(
     return fig
 
 
+def binary_transition_depths_fill_gaps(
+    df: pd.DataFrame,
+    curve_name: str,
+    md_column: str,
+    binary_numbers: Dict[Any, Dict[str, Any]],
+    binary_key: str,
+) -> List[Tuple[Any, Any, Any, Any]]:
+    """
+    Creates a list which contains information about when the binary flags switches
+    from one value to another.
+
+    Args:
+        df (pd.DataFrame): Dataframe containing binary data.
+        curve_name (str): Name of columns in df with binary data.
+        md_columns (str): Name of depth curve in df.
+        binary_numbers (Dict): Dict of binary mapping information.
+        binary_key (str): Key to specific binary information within dict.
+
+    Returns:
+        list: Returns a list of tuples of the form (Start depth of new value, End
+            depth of the value, Color representing the given value, human readamle name of
+            the value).
+    """
+    mask = (df[curve_name] != df[curve_name].shift()) | (
+        df[curve_name] != df[curve_name].shift(-1)
+    )
+    df2 = df[mask].reset_index().copy()
+    df2_shift_forward = df2.shift()
+    df2_shift_back = df2.shift(-1)
+    df2_shift_2back = df2_shift_back.shift(-1)
+
+    depths_lith_tuple_list = []
+
+    shift_start_half_interval = 0
+    for (
+        (_, row_nextnext),
+        (_, row_next),
+        (_, row),
+        (_, row_prev),
+    ) in zip(  # noqa: ignore
+        df2_shift_2back.iterrows(),
+        df2_shift_back.iterrows(),
+        df2.iterrows(),
+        df2_shift_forward.iterrows(),
+    ):
+        shift_end_half_interval = 0
+
+        if row_prev[curve_name] == row[curve_name]:
+            continue
+        elif (
+            row_prev[curve_name] != row[curve_name]
+            and row[curve_name] == row_next[curve_name]
+        ):
+            # In interval with different start and end point
+            if not np.isnan(row_nextnext[md_column]):
+                shift_end_half_interval = (
+                    row_nextnext[md_column] - row_next[md_column]
+                ) / 2
+
+            depths_lith_tuple_list.append(
+                (
+                    row[md_column] - shift_start_half_interval,
+                    row_next[md_column] + shift_end_half_interval,
+                    binary_numbers[row[curve_name]]["color"],
+                    binary_numbers[row[curve_name]][binary_key],
+                )
+            )
+        else:
+            # In interval with same start and endpoint
+            if not np.isnan(row_next[md_column]):
+                shift_end_half_interval = (row_next[md_column] - row[md_column]) / 2
+
+            depths_lith_tuple_list.append(
+                (
+                    row[md_column] - shift_start_half_interval,
+                    row[md_column] + shift_end_half_interval,
+                    binary_numbers[row[curve_name]]["color"],
+                    binary_numbers[row[curve_name]][binary_key],
+                )
+            )
+
+        shift_start_half_interval = shift_end_half_interval
+    return depths_lith_tuple_list
+
+
+def add_LITHOLOGY(
+    fig: go.Figure,
+    i_curve: int,
+    df: pd.DataFrame,
+    lithology_prediction_curve_name: str,
+    lithology_confidence_curve_name: str,
+    md_column: str,
+    lithology_numbers: Dict[float, Dict[str, Any]],
+    lithology_conf_numbers: Dict[float, Dict[str, Any]],
+) -> go.Figure:
+    """
+    Add LITHOLOGY column and LITHOLOGY confidence to passing go.Figure object.
+
+    Args:
+        fig (go.Figure): plotly graph_object Figure to append LITHOLOGY and LITHOLOGY confidence column
+        i_curve (int): index of column to add curve in subplot figure (from 1 to ncols)
+        df (pd.DataFrame): dataframe with information about LITHOLOGY curve,LITHOLOGY confidence curve and depth
+        lithology_prediction_curve_name (str): name of LITHOLOGY curve in dataframe
+        lithology_confidence_curve_name (str): name of LITHOLOGY CONFIDENCE curve in dataframe
+        md_column (str): name of depth curve in dataframe
+        lithology_numbers (Dict[int, Dict[str, Any]]): dictionary with lithology numbers as key with human readable name['lith'] and color['color'] for plot as value
+        lithology_conf_numbers (Dict[float, Dict[str, Any]]): dictionary with lithology conf numbers as key with color for plot as value['color']
+
+    Returns:
+        go.Figure: passing plotly graph_object Figure with added LITHOLOGY and LITHOLOGY confidence column in subplot
+    """
+
+    lithology_pred_transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=lithology_prediction_curve_name,
+        md_column=md_column,
+        binary_numbers=lithology_numbers,
+        binary_key="lith",
+    )
+    lithology_conf_transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=lithology_confidence_curve_name,
+        md_column=md_column,
+        binary_numbers=lithology_conf_numbers,
+        binary_key="conf",
+    )
+
+    left_col_value = -0.2
+    right_col_value = 1
+
+    # Plot lithology prediction
+    lith_in_legend = []
+    for depth_tuple in lithology_pred_transition_depths_list:
+        fig.add_trace(
+            go.Scatter(
+                x=[0, right_col_value],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                showlegend=False,
+            ),
+            row=1,
+            col=i_curve,
+        )
+
+        if depth_tuple[3] not in lith_in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, right_col_value],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                ),
+                row=1,
+                col=i_curve,
+            )
+            lith_in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, right_col_value],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    showlegend=False,
+                ),
+                row=1,
+                col=i_curve,
+            )
+
+    # plot separation line between lithology and conf
+    fig.add_trace(
+        go.Scatter(
+            x=[0] * len(df[md_column]),
+            y=df[md_column],
+            mode="lines",
+            marker=dict(
+                color="black",
+            ),
+            hoverinfo="none",
+        ),
+        row=1,
+        col=i_curve,
+    )
+
+    # Plot lithology confidence
+    lith_in_legend = []
+    for depth_tuple in lithology_conf_transition_depths_list:
+        fig.add_trace(
+            go.Scatter(
+                x=[left_col_value, 0],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                showlegend=False,
+            ),
+            row=1,
+            col=i_curve,
+        )
+
+        if depth_tuple[3] not in lith_in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[left_col_value, 0],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                ),
+                row=1,
+                col=i_curve,
+            )
+            lith_in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[left_col_value, 0],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    showlegend=False,
+                ),
+                row=1,
+                col=i_curve,
+            )
+
+    fig.update_xaxes(
+        title_text=lithology_prediction_curve_name,
+        row=1,
+        col=i_curve,
+        range=[left_col_value, right_col_value],
+    )
+    return fig
+
+
 def add_AC(
     fig: go.Figure, i_curve: int, df: pd.DataFrame, curve_name: str, md_column: str
 ) -> go.Figure:
@@ -715,30 +963,138 @@ def add_COAL_CALC_flag(
     # Define y-offset as a reference when displaying multiple x-axes
     y_offset = fig["layout"]["yaxis"]["domain"][0]
 
+    coal_numbers: Dict[float, Dict[str, str]] = {
+        1.0: {"coal": "COAL_FLAG", "color": "black"},
+        0.0: {"coal": "COAL_FLAG", "color": "#ffffff"},
+    }
+    calc_numbers: Dict[float, Dict[str, str]] = {
+        1.0: {"calc": "CALC_FLAG", "color": "orange"},
+        0.0: {"calc": "CALC_FLAG", "color": "#ffffff"},
+    }
+    coal_transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=coal_curve_name,
+        md_column=md_column,
+        binary_numbers=coal_numbers,
+        binary_key="coal",
+    )
+    calc_transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=calc_curve_name,
+        md_column=md_column,
+        binary_numbers=calc_numbers,
+        binary_key="calc",
+    )
+
+    # COAL FLAG
+    in_legend = []
+    for depth_tuple in coal_transition_depths_list:
+        if depth_tuple[2] == "#ffffff":
+            continue
+        fig.add_trace(
+            go.Scatter(
+                x=[0, 1],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                showlegend=False,
+            ),
+            row=1,
+            col=i_curve,
+        )
+
+        if depth_tuple[3] not in in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                ),
+                row=1,
+                col=i_curve,
+            )
+            in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    showlegend=False,
+                ),
+                row=1,
+                col=i_curve,
+            )
+
+    # plot separation line between lithology and conf
     fig.add_trace(
         go.Scatter(
-            x=df[coal_curve_name],
+            x=[0] * len(df[md_column]),
             y=df[md_column],
             mode="lines",
-            marker=dict(color="black"),
-            name="coal_flag",
-            fill="tozerox",
+            marker=dict(
+                color="black",
+            ),
+            hoverinfo="none",
         ),
         row=1,
         col=i_curve,
     )
-    fig.add_trace(
-        go.Scatter(
-            x=df[calc_curve_name],
-            y=df[md_column],
-            mode="lines",
-            marker=dict(color="orange"),
-            name="calc_flag",
-            fill="tozerox",
-            xaxis="x" + str(ncols + 1),
-            yaxis="y" + str(i_curve),
-        ),
-    )
+
+    # CALC FLAG
+    in_legend = []
+    for depth_tuple in calc_transition_depths_list:
+        if depth_tuple[2] == "#ffffff":
+            continue
+        fig.add_trace(
+            go.Scatter(
+                x=[0, 1],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                xaxis="x" + str(ncols + 1),
+                yaxis="y" + str(i_curve),
+            ),
+        )
+
+        if depth_tuple[3] not in in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    xaxis="x" + str(ncols + 1),
+                    yaxis="y" + str(i_curve),
+                ),
+            )
+            in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    xaxis="x" + str(ncols + 1),
+                    yaxis="y" + str(i_curve),
+                ),
+            )
     fig["layout"]["xaxis" + str(i_curve)] = {
         "anchor": "y" + str(i_curve),
         "domain": fig["layout"]["xaxis" + str(i_curve)]["domain"],
@@ -858,6 +1214,67 @@ def add_missedpay_prediction(
         go.Figure: passing plotly graph_object Figure with added MissedPay prediction in subplot
     """
 
+    # Plot flag pay prediction
+    pay_numbers: Dict[float, Dict[str, str]] = {
+        1.0: {"PAY_FLAG_ML": flag_curve_name, "color": "#008000"},
+        0.0: {"PAY_FLAG_ML": flag_curve_name, "color": "#ffffff"},
+    }
+    transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=flag_curve_name,
+        md_column=md_column,
+        binary_numbers=pay_numbers,
+        binary_key=flag_curve_name,
+    )
+
+    in_legend = []
+    for depth_tuple in transition_depths_list:
+        if depth_tuple[2] == "#ffffff":
+            continue
+        fig.add_trace(
+            go.Scatter(
+                x=[0, 1],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                showlegend=False,
+            ),
+            row=1,
+            col=i_curve,
+        )
+
+        if depth_tuple[3] not in in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                ),
+                row=1,
+                col=i_curve,
+            )
+            in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    showlegend=False,
+                ),
+                row=1,
+                col=i_curve,
+            )
+
     # Plot continous pay prediction
     fig.add_trace(
         go.Scatter(
@@ -871,22 +1288,6 @@ def add_missedpay_prediction(
         col=i_curve,
     )
 
-    # Plot flag pay prediction
-    fig.add_trace(
-        go.Scatter(
-            x=df[flag_curve_name],
-            y=df[md_column],
-            mode="lines",
-            opacity=0.5,
-            marker=dict(
-                color="green",
-            ),
-            fill="tozerox",
-            name=prediction_label,
-        ),
-        row=1,
-        col=i_curve,
-    )
     fig.update_xaxes(
         title_text=prediction_label,
         row=1,
@@ -981,165 +1382,6 @@ def add_mud_log_indicator(
     return fig
 
 
-def add_LITHOLOGY(
-    fig: go.Figure,
-    i_curve: int,
-    df: pd.DataFrame,
-    lithology_prediction_curve_name: str,
-    lithology_confidence_curve_name: str,
-    md_column: str,
-    lithology_numbers: Dict[int, Dict[str, Any]],
-    lithology_conf_numbers: Dict[float, Dict[str, Any]],
-) -> go.Figure:
-    """
-    Add LITHOLOGY column and LITHOLOGY confidence to passing go.Figure object.
-
-    Args:
-        fig (go.Figure): plotly graph_object Figure to append LITHOLOGY and LITHOLOGY confidence column
-        i_curve (int): index of column to add curve in subplot figure (from 1 to ncols)
-        df (pd.DataFrame): dataframe with information about LITHOLOGY curve,LITHOLOGY confidence curve and depth
-        lithology_prediction_curve_name (str): name of LITHOLOGY curve in dataframe
-        lithology_confidence_curve_name (str): name of LITHOLOGY CONFIDENCE curve in dataframe
-        md_column (str): name of depth curve in dataframe
-        lithology_numbers (Dict[int, Dict[str, Any]]): dictionary with lithology numbers as key with human readable name['lith'] and color['color'] for plot as value
-        lithology_conf_numbers (Dict[float, Dict[str, Any]]): dictionary with lithology conf numbers as key with color for plot as value['color']
-
-    Returns:
-        go.Figure: passing plotly graph_object Figure with added LITHOLOGY and LITHOLOGY confidence column in subplot
-    """
-
-    # FIXME: add lithology as stacked bar plot. Can also do it as a heat map
-    #
-    # Find total number of xaxis in fig json
-    # ncols = len(
-    #     [
-    #         key
-    #         for key in vars(fig.layout)["_compound_props"].keys()
-    #         if key[:5] == "xaxis"
-    #     ]
-    # )
-    #
-    # Define y-offset as a reference when displaying multiple x-axes
-    # y_offset = fig["layout"]["yaxis"]["domain"][0]
-
-    dfs_lith = []
-    lith_keys = df[lithology_prediction_curve_name].unique()
-    for lith_key in lith_keys:
-        df_lith = df.copy()
-        df_lith["LITHOLOGY"] = np.where(
-            df_lith[lithology_prediction_curve_name] == int(lith_key), 1, 0
-        )
-        dfs_lith.append(df_lith)
-
-    conf_left_col_value = -1
-    left_col_value = -0.2
-    right_col_value = 1
-    for i in range(len(lith_keys)):
-        fig.add_trace(
-            go.Scatter(
-                x=dfs_lith[i]["LITHOLOGY"],
-                y=dfs_lith[i][md_column],
-                mode="none",
-                marker=dict(color=lithology_numbers[lith_keys[i]]["color"], size=1),
-                name="LITHOLOGY",
-                hovertemplate=f"LITHOLOGY: {lithology_numbers[lith_keys[i]]['lith']}",
-                fill="tozerox",
-                fillcolor=lithology_numbers[lith_keys[i]]["color"],
-            ),
-            row=1,
-            col=i_curve,
-        )
-
-    if "LITHOLOGY_CONF" in df.columns:
-        dfs_lith_conf = []
-        lith_conf_vals = df[lithology_confidence_curve_name].unique()
-        for lith_conf_val in lith_conf_vals:
-            df_lith_conf = df.copy()
-            df_lith_conf["LITHOLOGY_CONF"] = np.where(
-                df_lith_conf["LITHOLOGY_CONF"] == lith_conf_val, 0, conf_left_col_value
-            )
-            dfs_lith_conf.append(df_lith_conf)
-
-        # plot separation line between lithology and conf
-        fig.add_trace(
-            go.Scatter(
-                x=[0] * len(df[md_column]),
-                y=df[md_column],
-                mode="lines",
-                marker=dict(
-                    color="black",
-                ),
-                hoverinfo="none",
-            ),
-            row=1,
-            col=i_curve,
-        )
-
-        for i in range(len(lith_conf_vals)):
-            # plot baseline for conf indicator
-            fig.add_trace(
-                go.Scatter(
-                    x=[conf_left_col_value] * len(df[md_column]),
-                    y=df[md_column],
-                    mode="lines",
-                    marker=dict(
-                        color="black",
-                    ),
-                ),
-                row=1,
-                col=i_curve,
-            )
-
-            # Plot conf lines
-            fig.add_trace(
-                go.Scatter(
-                    x=dfs_lith_conf[i]["LITHOLOGY_CONF"],
-                    y=dfs_lith_conf[i][md_column],
-                    mode="none",
-                    marker=dict(
-                        color=lithology_conf_numbers[lith_conf_vals[i]]["color"], size=1
-                    ),
-                    name="LITHOLOGY_CONF",
-                    hovertemplate=f"CONFIDENCE (from 0 to 1): {lith_conf_vals[i]}",
-                    fill="tonextx",
-                    fillcolor=lithology_conf_numbers[lith_conf_vals[i]]["color"],
-                ),
-                row=1,
-                col=i_curve,
-            )
-
-    else:
-        left_col_value = 0
-
-    fig.update_xaxes(
-        title_text="LITHOLOGY",
-        row=1,
-        col=i_curve,
-        range=[left_col_value, right_col_value],
-    )
-    # apply LITHOLOGY scale
-    # fig["layout"]["xaxis" + str(i_lith + 1)] = {
-    #    "anchor": "y" + str(i_lith + 1),
-    #    "domain": fig["layout"]["xaxis" + str(i_lith + 1)]["domain"],
-    #    "range": [left_col_value, right_col_value],
-    #    "tickfont": {"color": "black"},
-    #    "title": {"font": {"color": "black"}, "text": "LITHOLOGY"},
-    # }
-
-    # apply LITHOLOFY CONF scale
-    # fig["layout"]["xaxis" + str(ncols + 1)] = {
-    #    # "anchor": "free",
-    #    "overlaying": "x" + str(i_lith + 1),
-    #    "position": y_offset / 2,
-    #    "side": "right",
-    #    "range": [left_col_value, right_col_value],
-    #    "tickfont": {"color": "black"},
-    #    "title": {"font": {"color": "black"}, "text": "LITHOLOGY_CONF"},
-    # }
-
-    return fig
-
-
 def add_formations_and_groups(
     fig: go.Figure,
     i_curve: int,
@@ -1204,7 +1446,7 @@ def add_formations_and_groups(
             )
             / 2
         )
-    for label, formation_mid in zip(
+    for label, formation_mid in zip(  # noqa: ignore
         formations_dict[tops_level + "_labels"], formation_midpoints
     ):
         if formation_mid < df[md_column].max() and formation_mid > df[md_column].min():
@@ -1329,3 +1571,96 @@ def add_curve(
     )
 
     return fig
+
+
+def add_binary_curve(
+    fig: go.Figure,
+    i_curve: int,
+    df: pd.DataFrame,
+    flag_color: str,
+    curve_name: str,
+    md_column: str,
+) -> go.Figure:
+    """
+    Add binary column to passing go.Figure object.
+
+    Args:
+        fig (go.Figure): plotly graph_object Figure to append binary coulmn
+        i_curve (int): index of column to add curve in subplot figure (from 1 to ncols)
+        df (pd.DataFrame): dataframe with information about binary curve and depth
+        flag_color (str): Color of binary flag. Support color hex codes and matplotlib colors
+        curve_name (str): name of binary curve in dataframe
+        md_column (str): name of depth curve in dataframe
+
+    Returns:
+        go.Figure: passing plotly graph_object Figure with added binary curve in subplot
+    """
+
+    binary_numbers = {
+        1.0: {curve_name: curve_name, "color": flag_color},
+        0.0: {curve_name: curve_name, "color": "#ffffff"},
+    }
+    transition_depths_list = binary_transition_depths_fill_gaps(
+        df=df,
+        curve_name=curve_name,
+        md_column=md_column,
+        binary_numbers=binary_numbers,
+        binary_key=curve_name,
+    )
+
+    in_legend = []
+    for depth_tuple in transition_depths_list:
+        if depth_tuple[2] == "#ffffff":
+            continue
+        fig.add_trace(
+            go.Scatter(
+                x=[0, 1],
+                y=[depth_tuple[0], depth_tuple[0]],
+                mode="lines",
+                marker=dict(color=depth_tuple[2]),
+                name=depth_tuple[3],
+                showlegend=False,
+            ),
+            row=1,
+            col=i_curve,
+        )
+
+        if depth_tuple[3] not in in_legend:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                ),
+                row=1,
+                col=i_curve,
+            )
+            in_legend.append(depth_tuple[3])
+        else:
+            fig.add_trace(
+                go.Scatter(
+                    x=[0, 1],
+                    y=[depth_tuple[1], depth_tuple[1]],
+                    mode="lines",
+                    marker=dict(color=depth_tuple[2]),
+                    name=depth_tuple[3],
+                    fill="tonexty",
+                    fillcolor=depth_tuple[2],
+                    showlegend=False,
+                ),
+                row=1,
+                col=i_curve,
+            )
+
+    fig.update_xaxes(
+        title_text=curve_name,
+        row=1,
+        col=i_curve,
+        range=[0.0, 1.0],
+    )
+
+    return fig
