@@ -33,7 +33,7 @@ import akerbp.mlpet.imputers as imputers
 import akerbp.mlpet.utilities as utilities
 
 
-def set_as_nan(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
+def set_as_nan(df_: pd.DataFrame, **kwargs) -> pd.DataFrame:
     """
     Replaces the provided numerical and categorical values with np.nan in the
     respective numerical and categorical columns. If numerical or categorical
@@ -55,14 +55,16 @@ def set_as_nan(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
         df (pd.Dataframe): The original dataframe filled with np.nan where
             requested
     """
+    df = df_.copy()
     # Processing inputs
     numerical_curves: List[str] = kwargs.get("numerical_curves", None)
     categorical_curves: List[str] = kwargs.get("categorical_curves", None)
     numerical_value = kwargs.get("numerical_value")
     categorical_value = kwargs.get("categorical_value")
+    warn = kwargs.get("warn", True)
 
     inferred_numeric, inferred_categorical = utilities.get_col_types(
-        df, categorical_curves
+        df, categorical_curves, warn
     )
     # Ensure user is using method the correct way
     if numerical_value is not None:
@@ -114,11 +116,11 @@ def remove_outliers(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
     outlier_curves = kwargs.get("outlier_curves", None)
 
     if outlier_curves is not None:
-        len_df = np.array([len(df)])
         with np.errstate(divide="ignore", invalid="ignore"):
             if "GR" in outlier_curves:
                 outliers = df[(df.GR < 0) | (df.GR > 250)]
-                if len(outliers) / len_df > th:
+                valid_GR = df.GR.notna().sum()
+                if len(outliers) / valid_GR > th:
                     warnings.warn(
                         f"GR has more than {th*100}% of its values lower"
                         " than 0 or higher than 250. Replacing them with either 0"
@@ -132,7 +134,8 @@ def remove_outliers(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
             for resistivity in ["RMIC", "RSHA", "RMED", "RDEP"]:
                 if resistivity in outlier_curves:
                     outliers = df[resistivity] > 100
-                    if outliers.sum() / len_df > th:
+                    valid_res = df[resistivity].notna().sum()
+                    if outliers.sum() / valid_res > th:
                         warnings.warn(
                             f"{resistivity} has more than {th*100}% of its values higher"
                             " than 100. Note: This column names is the name after it has"
@@ -146,7 +149,8 @@ def remove_outliers(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
 
             if "NEU" in outlier_curves:
                 outliers = (df.NEU < -0.5) | (df.NEU > 1)
-                ratio = outliers.sum() / len_df
+                valid_NEU = df.NEU.notna().sum()
+                ratio = outliers.sum() / valid_NEU
                 if ratio > th:
                     warnings.warn(
                         f"NEU has {ratio*100}% of its values higher than 1"
@@ -157,7 +161,8 @@ def remove_outliers(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
 
             if "PEF" in outlier_curves:
                 outliers = df.PEF > 10
-                if outliers.sum() / len_df > th:
+                valid_PEF = df.PEF.notna().sum()
+                if outliers.sum() / valid_PEF > th:
                     warnings.warn(
                         f"PEF has more than {th*100}% of its values higher than 10"
                     )
@@ -189,7 +194,9 @@ def remove_small_negative_values(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
     nan_threshold = kwargs.get("nan_threshold")
     numerical_curves = kwargs.get("numerical_curves", None)
     if numerical_curves is None:
-        numerical_curves, _ = utilities.get_col_types(df)
+        # Only interested in numerical columns so no need to flood console with
+        # warnings related to categorical curves
+        numerical_curves, _ = utilities.get_col_types(df, warn=False)
     if nan_threshold is not None:
         # remove small negative values
         for col in numerical_curves:
@@ -241,8 +248,9 @@ def fillna_with_fillers(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
     cat_filler = kwargs.get("cat_filler")
     numerical_curves = kwargs.get("numerical_curves", None)
     categorical_curves = kwargs.get("categorical_curves", None)
+    warn = kwargs.get("warn", True)
     inferred_numeric, inferred_categorical = utilities.get_col_types(
-        df, categorical_curves
+        df, categorical_curves, warn
     )
 
     if numerical_curves is None:
@@ -295,9 +303,10 @@ def encode_columns(df: pd.DataFrame, **kwargs) -> pd.DataFrame:
     groups_map: Dict[str, float] = kwargs.get("groups_map", None)
     systems_map: Dict[str, float] = kwargs.get("systems_map", None)
     missing_encoding_value: float = kwargs.get("missing_encoding_value", -1.0)
+    warn = kwargs.get("warn", True)
 
     if columns_to_encode is None:
-        _, columns_to_encode = utilities.get_col_types(df, columns_to_encode)
+        _, columns_to_encode = utilities.get_col_types(df, warn=warn)
 
     # Normalize before mapping
     df = utilities.normalize_group_formation_system(
