@@ -18,5 +18,6 @@ def test_load_from_las():
             "src/akerbp/mlpet/tests/data/15_9-23.las",
             "src/akerbp/mlpet/tests/data/25_2-7.las",
             "src/akerbp/mlpet/tests/data/35_12-1.las",
-        ]
+        ],
+        metadata=["WELL"],  # Retrieve well name from metadata
     )
