@@ -1,3 +1,4 @@
+import pytest
 from pandas.testing import assert_frame_equal
 
 from akerbp.mlpet import feature_engineering
@@ -10,11 +11,13 @@ from akerbp.mlpet.tests.data.data import (
     VERTICAL_DEPTHS_MAPPER,
     VERTICAL_DF,
 )
-from akerbp.mlpet.tests.data.kubeflow_config import ID_COLUMN
-from akerbp.mlpet.tests.data.kubeflow_config import (
-    KUBEFLOW_MODEL_URL_VSH as KUBEFLOW_MODEL_URL,
-)
-from akerbp.mlpet.tests.data.kubeflow_config import VSH_HEADER, VSH_KWARGS
+
+ID_COLUMN = "well_name"
+VSH_KWARGS = {
+    "nan_numerical_value": -9999,
+    "nan_textual_value": "MISSING",
+    "VSH_curves": ["GR"],
+}
 
 FORMATION_DF = FORMATION_DF_WITH_SYSTEMS.drop(columns=["SYSTEM"])
 DEPTH_COL = "DEPTH"
@@ -80,17 +83,71 @@ def test_add_vertical_depths_using_client():
     )
 
     assert_frame_equal(
-        df_with_vertical_depths.sort_index(axis=1), VERTICAL_DF.sort_index(axis=1)
+        df_with_vertical_depths.sort_index(axis=1),
+        VERTICAL_DF.sort_index(axis=1),
     )
 
 
 def test_add_vertical_depths_when_no_client_nor_mapping_is_provided():
-    _ = feature_engineering.add_vertical_depths(
+    df_with_vertical_depths = feature_engineering.add_vertical_depths(
         VERTICAL_DF[[DEPTH_COL, ID_COLUMN]],
         id_column=ID_COLUMN,
         md_column=DEPTH_COL,
     )
 
+    assert_frame_equal(
+        df_with_vertical_depths.sort_index(axis=1),
+        VERTICAL_DF.sort_index(axis=1),
+    )
+
+
+def test_add_wellbore_coordinates_no_client_nor_mapping_is_provided():
+    df_with_wellbore_coordinates = feature_engineering.add_wellbore_coordinates(
+        VERTICAL_DF[[DEPTH_COL, ID_COLUMN]],
+        id_column=ID_COLUMN,
+        md_column=DEPTH_COL,
+    )
+    coordinate_columns = ["X", "Y"]
+    assertions = [
+        col in df_with_wellbore_coordinates.columns for col in coordinate_columns
+    ]
+    assert len(assertions) == sum(assertions)
+
+
+def test_add_wellbore_coordinates_wrong_trajectory_type_override_with_default():
+    df_with_wellbore_coordinates = feature_engineering.add_wellbore_coordinates(
+        VERTICAL_DF[[DEPTH_COL, ID_COLUMN]],
+        id_column=ID_COLUMN,
+        md_column=DEPTH_COL,
+        trajectory_type="wrong_trajectory_type",
+    )
+    coordinate_columns = ["X", "Y"]
+    assertions = [
+        col in df_with_wellbore_coordinates.columns for col in coordinate_columns
+    ]
+    assert len(assertions) == sum(assertions)
+
+
+def test_add_trajectory_data_no_client_nor_mapping_is_provided():
+    df_with_trajectory_data = feature_engineering.add_trajectory_data(
+        VERTICAL_DF[[DEPTH_COL, ID_COLUMN]],
+        id_column=ID_COLUMN,
+        md_column=DEPTH_COL,
+    )
+    trajectory_columns = ["X", "Y", "TVDBML", "TVDSS", "TVDKB"]
+    assertions = [col in df_with_trajectory_data.columns for col in trajectory_columns]
+    assert len(assertions) == sum(assertions)
+
+
+def test_add_trajectory_data_wrong_trajectory_type_raise_error():
+    with pytest.raises(ValueError, match="Invalid trajectory_type provided!"):
+        _ = feature_engineering.add_trajectory_data(
+            VERTICAL_DF[[DEPTH_COL, ID_COLUMN]],
+            id_column=ID_COLUMN,
+            md_column=DEPTH_COL,
+            trajectory_type="wrong_trajectory_type",
+        )
+
 
 def test_add_well_metadata():
     metadata = {"30/11-6 S": {"FOO": 0}, "25/7-4 S": {"FOO": 1}}
@@ -132,52 +189,3 @@ def test_add_petrophysical_features_add_VSH_call_CDF_model_return_only_vsh_aut()
     )
     output_curves = result.columns
     assert "VSH" in output_curves, "'VSH' not added to dataframe"
-
-
-def test_add_petrophysical_features_add_VSH_from_kubeflow_return_only_vsh_aut():
-    petrophysical_features = ["VSH"]
-    result = feature_engineering.add_petrophysical_features(
-        df=TEST_DF,
-        id_column=ID_COLUMN,
-        keyword_arguments=VSH_KWARGS,
-        kubeflow_model_url=KUBEFLOW_MODEL_URL,
-        request_header=VSH_HEADER,
-        petrophysical_features=petrophysical_features,
-    )
-    output_curves = set(result.columns)
-    assert {"VSH"}.issubset(output_curves), "'VSH' not added to dataframe"
-
-
-def test_add_petrophysical_features_add_VSH_from_kubeflow_return_composite_curves_no_CI():
-    petrophysical_features = ["VSH"]
-    keyword_arguments = VSH_KWARGS.copy()
-    keyword_arguments["return_only_vsh_aut"] = False
-    result = feature_engineering.add_petrophysical_features(
-        df=TEST_DF,
-        id_column=ID_COLUMN,
-        keyword_arguments=keyword_arguments,
-        kubeflow_model_url=KUBEFLOW_MODEL_URL,
-        request_header=VSH_HEADER,
-        petrophysical_features=petrophysical_features,
-    )
-    output_curves = result.columns.tolist()
-    assert {"VSH", "VSH_GR_AUT_QCFLAG"}.issubset(
-        set(output_curves)
-    ) and "VSH_AUT_P90" not in output_curves
-
-
-def test_add_petrophysical_features_add_VSH_from_kubeflow_return_composite_curves_and_CI():
-    petrophysical_features = ["VSH"]
-    keyword_arguments = VSH_KWARGS.copy()
-    keyword_arguments["return_only_vsh_aut"] = False
-    result = feature_engineering.add_petrophysical_features(
-        df=TEST_DF,
-        id_column=ID_COLUMN,
-        keyword_arguments=keyword_arguments,
-        kubeflow_model_url=KUBEFLOW_MODEL_URL,
-        request_header=VSH_HEADER,
-        return_CI=True,
-        petrophysical_features=petrophysical_features,
-    )
-    output_curves = result.columns.tolist()
-    assert {"VSH", "VSH_GR_AUT_QCFLAG", "VSH_AUT_P90"}.issubset(set(output_curves))
