@@ -9,11 +9,11 @@ from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
 import numpy as np
 import numpy.typing as npt
 import pandas as pd
-import requests
 from cognite.client import ClientConfig, CogniteClient
-from cognite.client.credentials import APIKey
+from cognite.client.credentials import OAuthClientCredentials
 from cognite.client.data_classes import Asset, AssetList
 from numpy import float64
+from scipy.interpolate import interp1d
 
 import akerbp.mlpet.data
 import akerbp.mlpet.preprocessors as preprocessors
@@ -606,7 +606,7 @@ def get_well_metadata(  # noqa: C901
     def _find_best_match(assetlist: AssetList, wellName: str) -> str:
         # Compares only the alphanumerics of the wellName (ie. punctuation removed)
         # If no match is found it returns an empty string
-        pat = re.compile(r"[\W_]+")
+        pat = re.compile(r"[^a-zA-Z0-9\-]+")
         for asset in assetlist:
             name: str = asset.name
             if pat.sub("", name) == pat.sub("", wellName):
@@ -916,12 +916,133 @@ def get_formation_tops(  # noqa: C901
     return formation_tops_mapper
 
 
+def get_trajectory_mapper_from_cdf(
+    well_names: List[str],
+    client: CogniteClient,
+) -> Dict[str, Dict[str, List[float]]]:
+    """Makes a query to CDF for all provided wells and extracts trajectory data, i.e.
+    vertical- and measured depths as well as coordinates.
+
+    The resulting dictionary have keys representing each well being queried, with values being
+    a mapping dictionary with the following keys
+        - MD
+        - TVDKB
+        - TVDSS
+        - TVDBML
+        - X
+        - Y
+
+    Note that the resulting values are not for the entire wellbore, so these needs to be interpolated
+    using measured depth (MD) as a reference.
+
+    Args:
+        well_name (List[str]): list of well names
+        client (CogniteClient): cognite client
+
+    Returns:
+        Dict[str, Dict[str, List[float]]]: Dictionary containing trajectory data (values) for each well (keys)
+    """
+    trajectory_mapper = {}
+    for well in well_names:
+        # Trajectory in CDF is fetched from GIS, which agian is fetched from NPD.
+        # NPD do not keep track of technical sidetrackings.
+        well_name = well.split("T")[0].rstrip()
+        well_data_cdf = client.sequences.list(
+            metadata={"wellbore_name": well_name, "type": "trajectory"},
+            limit=None,
+        )
+        if len(well_data_cdf) == 0:
+            warnings.warn(f"No trajectory data was found for well {well}. Skipping it!")
+            continue
+        well_df_discrete = client.sequences.data.retrieve_dataframe(
+            id=well_data_cdf[0].id,
+            start=0,
+            end=None,
+        )
+        if len(well_df_discrete) == 0:
+            warnings.warn(f"No trajectory data was found for well {well}. Skipping it!")
+            continue
+        well_df_discrete = well_df_discrete.drop_duplicates()
+        md_query = well_df_discrete["MD"].to_list()
+        tvdkb_query = well_df_discrete["TVDKB"].to_list()
+        tvdss_query_ = well_df_discrete["TVDSS"].to_list()
+        tvdss_query = [-x for x in tvdss_query_]
+        tvdbml_query = well_df_discrete["TVDBML"].to_list()
+        xloc_query = well_df_discrete["X"].to_list()
+        yloc_query = well_df_discrete["Y"].to_list()
+
+        trajectory_mapper_well = {
+            "MD": md_query,
+            "TVDKB": tvdkb_query,
+            "TVDSS": tvdss_query,
+            "TVDBML": tvdbml_query,
+            "X": xloc_query,
+            "Y": yloc_query,
+        }
+        trajectory_mapper[well] = trajectory_mapper_well
+
+    return trajectory_mapper
+
+
+def drop_fields_from_trajectory_mapper(
+    trajectory_mapper: Dict[str, Dict[str, List[float]]], fields_to_drop: List[str]
+) -> Dict[str, Dict[str, List[float]]]:
+    """Drop specified fields from the trajectory mapping dictionary from CDF
+
+    Args:
+        trajectory_mapper (Dict[str, List[float]]): trajectory mapping dictionary
+        fields_to_drop (List[str]): fields to exclude from the mapping dictionary
+
+    Returns:
+        Dict[str, Dict[str, List[float]]]: trajectory mapping dictionary
+    """
+    mapper = {}
+    for well, trajectory_dict in trajectory_mapper.items():
+        for field in fields_to_drop:
+            try:
+                trajectory_dict.pop(field)
+            except KeyError:
+                warnings.warn(
+                    f"Specified field '{field}' does not exist in the trajectory mapping and can not be removed"
+                )
+                continue
+        mapper[well] = trajectory_dict
+    return mapper
+
+
+def get_wellbore_coordinates(
+    well_names: List[str],
+    client: CogniteClient,
+) -> Dict[str, Dict[str, List[float]]]:
+    """Returns a dictionary with well names as keys, and a dictionary with
+    X and Y coordinates as well as measured depth (MD) as values.
+
+    These are values at discrete points along the wellbore.
+
+    Args:
+        well_names (List[str]): List of well names
+        client (CogniteClient): CogniteClient object
+
+    Returns:
+        Dict[str, Dict[str, List[float]]]: Dictionary with well names as keys,
+        and a dictionary with x, y, and z values as values.
+    """
+    fields_to_drop = ["TVDKB", "TVDSS", "TVDBML"]
+    trajectory_mapper = get_trajectory_mapper_from_cdf(well_names, client)
+    coordinates_mapper = drop_fields_from_trajectory_mapper(
+        trajectory_mapper, fields_to_drop
+    )
+    return coordinates_mapper
+
+
 def get_vertical_depths(
     well_names: List[str],
     client: CogniteClient,
 ) -> Dict[str, Dict[str, List[float]]]:
-    """Makes trajectory queries to CDF for all provided wells and extracts vertical- and measured depths.
-    These depths will further down the pipeline be used to interpolate the vertical depths along all the entire wellbores.
+    """Returns a dictionary with well names as keys, and a dictionary with
+    vertical- and measured depths as values.
+
+    These are values at discrete points along the wellbore.
 
     Args:
         well_names (List[str]): list of well names
@@ -930,45 +1051,55 @@ def get_vertical_depths(
     Returns:
         Dict[str, Dict[str, List[float]]]: Dictionary containing vertical- and measured depths (values) for each well (keys), list of wells with empty trajectory query to CDF
     """
-    vertical_depths_mapper = {}
-    for well in well_names:
-        # Trajectory in CDF is fetched from GIS, which agian is fetched from NPD.
-        # NPD do not keep track of technical sidetrackings.
-        well_name = well.split("T")[0].rstrip()
+    fields_to_drop = ["X", "Y"]
+    trajectory_mapper = get_trajectory_mapper_from_cdf(well_names, client)
+    vertical_depths_mapper = drop_fields_from_trajectory_mapper(
+        trajectory_mapper, fields_to_drop
+    )
 
-        well_data_cdf = client.sequences.list(
-            metadata={"wellbore_name": well_name, "type": "trajectory"}, limit=None
-        )
-        if len(well_data_cdf) == 0:
-            warnings.warn(
-                f"No trajectory information was found for {well}. Skipping it!"
-            )
-            continue
-        well_df_discrete = client.sequences.data.retrieve_dataframe(
-            id=well_data_cdf[0].id, start=0, end=None
-        )
-        if len(well_df_discrete) == 0:
-            warnings.warn(
-                f"No trajectory information was found for {well}. Skipping it!"
-            )
-            continue
-        well_df_discrete = well_df_discrete.drop_duplicates()
-        md_query = well_df_discrete["MD"].to_list()
-        tvdkb_query = well_df_discrete["TVDKB"].to_list()
-        tvdss_query = well_df_discrete["TVDSS"].to_list()
-        tvdss_query = [-x for x in tvdss_query]
-        tvdbml_query = well_df_discrete["TVDBML"].to_list()
-
-        vertical_dict_well = {
-            "TVDKB": tvdkb_query,
-            "TVDSS": tvdss_query,
-            "TVDBML": tvdbml_query,
-            "MD": md_query,
-        }
-        vertical_depths_mapper[well] = vertical_dict_well
     return vertical_depths_mapper
 
 
+def interpolate_discrete_trajectory_data_along_wellbore(
+    df: pd.DataFrame,
+    id_column: str,
+    md_column: str,
+    trajectory_mapping: Dict[str, Dict[str, List[float]]],
+) -> pd.DataFrame:
+    """Linearly interpolate the discrete trajectory data along the entire wellbore
+
+    Args:
+        df (pd.DataFrame): input data
+        id_column (str): column representing well name
+        md_column (str): column representing measured depth
+        trajectory_mapping (Dict[str, Dict[str, List[float]]]): trajectory mapping
+
+    Returns:
+        pd.DataFrame: output data with interpolated trajectory data as additinoal colmns
+    """
+    df_ = df.copy()
+    for well in trajectory_mapping:
+        md_interpolate = df_.loc[df_[id_column] == well, md_column].to_list()
+        trajectory_data = trajectory_mapping[well]
+        md = trajectory_data["MD"]
+        for trajectory_field in trajectory_data.keys():
+            if trajectory_field == "MD":
+                continue
+            trajectory_values = trajectory_data[trajectory_field]
+            with warnings.catch_warnings(record=True) as w:
+                f = interp1d(x=md, y=trajectory_values, fill_value="extrapolate")
+                interpolated_trajectory_values = f(md_interpolate)
+            if w:
+                warnings.warn(
+                    f"Interpolation of {trajectory_field} for well {well} triggered a "
+                    f"runtime warning: {w[0].message}"
+                )
+            df_.loc[
+                df_[id_column] == well, trajectory_field
+            ] = interpolated_trajectory_values
+    return df_
+
+
 def get_calibration_map(
     df: pd.DataFrame,
     curves: List[str],
@@ -1286,7 +1417,9 @@ def estimate_parameter(
 
 
 def get_cognite_client(
-    cognite_api_key: Optional[str] = None,
+    client_id: Optional[str] = None,
+    client_secret: Optional[str] = None,
+    permission_scope: str = "read",
     cognite_project_id: str = "akbp-subsurface",
     cognite_client_id: str = "mlpet",
 ) -> CogniteClient:
@@ -1294,56 +1427,69 @@ def get_cognite_client(
     Helper function to create a CogniteClient instance.
 
     Args:
-        cognite_api_key (str): The API key to use for the CogniteClient
-        cognite_project_id (int): The project ID to use for the CogniteClient
+        client_id (str): Client id to authenticate the client with
+        client_secret (str): Client secret to authenticate the client with
+        cognite_project_id (str): The project ID to use for the CogniteClient, Defaults to akbp-subsurface
         cognite_client_id (str): The client ID to use for the CogniteClient
+        persmission_scope (str): The permission scope to use for the CogniteClient, either "read" or "write", deafult to "read"
 
         Returns:
             CogniteClient: The created CogniteClient instance
     """
-    e = None
-    if cognite_api_key is None:
-        try:
-            cognite_api_key = os.environ["COGNITE_API_KEY"]
-        except KeyError:
-            try:
-                from akerbp.mlops.core import config
-
-                cognite_api_key = config.api_keys["data"]
-            except ImportError:
-                # akerbp.mlops is not installed so ignore
-                pass
-            except KeyError:
-                # Could not find the data key in config try to use whichever
-                # key is available
-                v = config.api_keys.values()
-                if v:
-                    cognite_api_key = v[0]
-            except Exception as exc:
-                e = exc
-
-    if cognite_api_key is None:
+    permission = permission_scope.lower()
+    if permission not in ["read", "write"]:
         raise ValueError(
-            "No API key provided, none could be imported from akerbp.mlops and no environment variable "
-            "COGNITE_API_KEY was found!"
+            f"Invalid permission scope '{permission_scope}', must be either 'read' or 'write'"
+        )
+
+    cognite_project_id = "akbp-subsurface"
+    cognite_client_id = "mlpet-client"
+    base_url, tenant_id = None, None
+    try:
+        base_url = os.environ["COGNITE_OIDC_BASE_URL"]
+    except KeyError as e:
+        raise Exception(
+            "Need to set COGNITE_OIDC_BASE_URL to initialize a cognite client"
+        ) from e
+    try:
+        tenant_id = os.environ["COGNITE_TENANT_ID"]
+    except KeyError as e:
+        raise Exception(
+            "Need to set COGNITE_TENANT_ID to initialize a cognite client"
+        ) from e
+    try:
+        if client_id is None or client_secret is None:
+            from akerbp.mlops.core.config import client_secrets as secrets
+
+            client_id = secrets[f"id-{permission}"]
+            client_secret = secrets[f"secret-{permission}"]
+        else:
+            pass
+    except KeyError as e:
+        raise Exception(
+            f"Need to set client id and secret for permission scope {permission_scope} as environment variables to initialize a client"
         ) from e
 
-    # Assuming COGNITE_API_KEY is set in the environment
-    credentials = APIKey(cognite_api_key)
+    credentials = OAuthClientCredentials(
+        token_url=f"https://login.microsoftonline.com/{tenant_id}/oauth2/v2.0/token",
+        client_id=client_id,
+        client_secret=client_secret,
+        base_url=base_url,
+        scopes=[f"{base_url}/.default"],
+    )
+
     client_config = ClientConfig(
         client_name=cognite_client_id,
         project=cognite_project_id,
         credentials=credentials,
     )
-    return CogniteClient(client_config)
+    return CogniteClient(config=client_config)
 
 
 def run_deployed_model(
     df: pd.DataFrame,
     id_column: str,
     keyword_arguments: Dict[str, Any],
-    kubeflow_model_url: Optional[str] = None,
-    header: Optional[Dict[Any, Any]] = None,
     cdf_external_id: Optional[str] = None,
     **kwargs,
 ) -> pd.DataFrame:
@@ -1353,7 +1499,6 @@ def run_deployed_model(
     Args:
         df (pd.DataFrame): The dataframe to run the model on
         id_column (str): The column in the dataframe that contains the well names
-        kubeflow_model_url (str): The URL to the deployed model
         cdf_external_id (str): The external ID of the Cognite Data Fusion function
         keyword_arguments (Dict[str, Any]): Keyword arguments to pass to the model
 
@@ -1386,17 +1531,8 @@ def run_deployed_model(
 
     if cdf_external_id is not None:
         predictions = run_CDF_function(in_data, cdf_external_id, **kwargs)
-    elif kubeflow_model_url is not None:
-        if header is not None:
-            predictions = run_kubeflow_model(
-                in_data, kubeflow_model_url, header=header, **kwargs
-            )
-        else:
-            predictions = run_kubeflow_model(in_data, kubeflow_model_url, **kwargs)
     else:
-        raise ValueError(
-            "Neither a Cognite Data Fusion function nor a Kubeflow model URL was provided!"
-        )
+        raise ValueError("No Cognite Data Fusion function was provided!")
 
     for well in predictions:
         pred = pd.DataFrame.from_dict(well)
@@ -1434,7 +1570,7 @@ def run_CDF_function(
     """
     # Create the CogniteClient instance
     if client is None:
-        client = get_cognite_client()
+        client = get_cognite_client(permission_scope="write")
     function = client.functions.retrieve(external_id=cdf_external_id)
     if function is None:
         raise ValueError(
@@ -1457,77 +1593,3 @@ def run_CDF_function(
         predictions = results["prediction"]
 
     return predictions
-
-
-def run_kubeflow_model(
-    in_data: Dict[str, Any],
-    model_url: str,
-    header: Optional[Dict[Any, Any]] = None,
-    session: Optional[requests.Session] = None,
-    **kwargs,
-) -> pd.DataFrame:
-    """
-    Helper function to send a http(s) request to a model hosted on a (kubeflow) cluster.
-    Note: this function assumes requests are sent to url on the form
-    'http(s)://(...)/model_name/endpoint',
-    where 'endpoint' can be either 'metadata' or 'predict'.
-
-        Args:
-            in_data: The payload to send to the kubeflow model
-            model_url (str): The URL to the kubeflow model
-            session (requests.Session): The requests session to use for sending the request
-        Returns:
-            pd.DataFrame: The dataframe with the results of the function
-        Raises:
-            ValueError: If an invalid endpoint is requested, i.e. other than 'predict' and 'metadata'
-            ValueError: If request exits with a status code other than 200
-    """
-    model_name = model_url.split("/")[-2]
-    endpoint = model_url.split("/")[-1]
-    if endpoint == "metadata":
-        method = "get"
-    elif endpoint == "predict":
-        method = "post"
-    else:
-        raise ValueError(
-            f"Invalid request: Model {model_name} does not have a '{endpoint}' endpoint"
-        )
-    # Create a session to send the request
-    if session is None:
-        session = requests.Session()
-
-    # Send the request
-    if method == "post":
-        try:
-            if header is not None:
-                response = session.post(
-                    url=model_url,
-                    json=in_data,
-                    headers=header,
-                )
-            else:
-                response = session.post(model_url, json=in_data)
-        except requests.exceptions.ConnectionError as e:
-            raise ValueError(f"Failed to connect to endpoint '{model_url}'") from e
-    else:
-        try:
-            if header is not None:
-                response = session.get(
-                    url=model_url,
-                    headers=header,
-                )
-            else:
-                response = session.get(model_url)
-        except requests.exceptions.ConnectionError as e:
-            raise ValueError(f"Failed to connect to endpoint '{model_url}'") from e
-
-    # Check that the response is OK
-    if response.status_code != 200:
-        raise ValueError(
-            f"Request to {model_url} failed with status code {response.status_code}! See response for details: {response.text}"
-        )
-    # Get the predictions/metadata
-    if endpoint == "metadata":
-        return response.json()
-    else:
-        return response.json()["prediction"]
